@@ -1330,6 +1330,7 @@ class RadioBtnPopup:
     self.pop_control = wx.BoxSizer(wx.HORIZONTAL)
     self.first_button = QuiskPushbutton(parent, self.OnFirstButton, labels[0], text_color=conf.color_popchoice)
     self.first_button.decoration = u'\u21D2'
+    self.first_button.idName = idName
     self.second_button = QuiskBitmapButton(parent, self.OnSecondButton, _bitmap_menupop, use_right=True)
     self.pop_control.Add(self.first_button, 1, flag=wx.ALIGN_CENTER_VERTICAL)
     self.pop_control.Add(self.second_button, 0, flag=wx.ALIGN_CENTER_VERTICAL|wx.LEFT, border=2)
@@ -1447,6 +1448,8 @@ class RadioBtnPopup:
     return self.first_button.GetSize()
   def Shortcut(self, event, button_name=None):
     self.SetLabel(button_name, True)
+  def GetSelectedButton(self):		# return the selected button
+    return self.RbDialog.RbGroup.GetSelectedButton()
 
 class FreqSetter(wx.TextCtrl):
   def __init__(self, parent, x, y, label, fmin, fmax, freq, command):
